@@ -129,7 +129,7 @@ public class PlannerDataObjectEditorTest
         verify(assetsUsageService,
                times(1)).getAssetUsages(anyString(),
                                         any(),
-                                        any(Path.class));
+                                        any());
     }
 
     @Test
@@ -539,4 +539,15 @@ public class PlannerDataObjectEditorTest
         verify(view,
                times(1)).showPlanningSolutionHelpIcon(true);
     }
+
+    @Test
+    public void getFindClassUsagesCallbackObjectWithoutContext() {
+        PlannerDataObjectEditor objectEditor = createObjectEditor();
+        objectEditor.onContextChange(null);
+
+        objectEditor.getFindClassUsagesCallback().callback(Collections.emptyList());
+
+        verify(view, never()).enablePlanningSolutionCheckBox(anyBoolean());
+        verify(view, never()).showPlanningSolutionHelpIcon(anyBoolean());
+    }
 }
